@@ -4,14 +4,15 @@ use warnings;
 use strict;
 use Carp qw( croak );
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 my @tone_list = ('C', 'C#', 'D', 'D#', 'E', 'F', 'F#', 'G', 'G#', 'A', 'A#', 'B',
                  'C', 'C#', 'D', 'D#', 'E', 'F', 'F#', 'G', 'G#', 'A', 'A#', 'B');
 
-my $base_chord_list = {
+our $base_chord_list = {
     'base'     => '0,4,7',
     '-5'       => '0,4,6',
+    '-6'       => '0,4,7,8',
     '6'        => '0,4,7,9',
     '6(9)'     => '0,4,7,9,14',         '69'       => '0,4,7,9,14',
     'M7'       => '0,4,7,11',
@@ -22,6 +23,7 @@ my $base_chord_list = {
     '7'        => '0,4,7,10',
     '7(b5)'    => '0,4,6,10',           '7b5'      => '0,4,6,10',
     '7(-5)'    => '0,4,6,10',           '7-5'      => '0,4,6,10',
+    '7(#5)'    => '0,4,7,8,10',         '7#5'      => '0,4,7,8,10',
     '7(b9)'    => '0,4,7,10,13',        '7b9'      => '0,4,7,10,13',
     '7(-9)'    => '0,4,7,10,13',        '7-9'      => '0,4,7,10,13',
     '-9'       => '0,4,7,10,13',
@@ -44,6 +46,7 @@ my $base_chord_list = {
     'm7'       => '0,3,7,10',
     'm7(b5)'   => '0,3,6,10',            'm7b5'    => '0,3,6,10',
     'm7(-5)'   => '0,3,6,10',            'm7-5'    => '0,3,6,10',
+    'm7(#5)'   => '0,3,8,10',            'm7#5'    => '0,3,8,10',
     'm7(9)'    => '0,3,7,10,14',         'm79'     => '0,3,7,10,14',
     'm9'       => '0,3,7,10,14',
     'm7(9,11)' => '0,3,7,10,14,17',
@@ -55,6 +58,8 @@ my $base_chord_list = {
     'aug7'     => '0,4,8,10',
     'augM7'    => '0,4,8,11',
     'aug9'     => '0,4,8,10,14',
+    'sus2'     => '0,2,7',
+    'sus'      => '0,5,7',
     'sus4'     => '0,5,7',
     '7sus4'    => '0,5,7,10',
     'add2'     => '0,2,4,7',
